scripts/install.py

branch
eric7
changeset 10503
6a37b6ac3928
parent 10496
f9925e08dbce
child 10513
805a0450862d
--- a/scripts/install.py	Sun Jan 14 13:02:05 2024 +0100
+++ b/scripts/install.py	Tue Jan 16 14:18:52 2024 +0100
@@ -69,13 +69,13 @@
 installInfo = {}
 installCwd = ""
 
-# Define blacklisted versions of the prerequisites
-BlackLists = {
+# Define blocklisted versions of the prerequisites
+BlockLists = {
     "sip": [],
     "PyQt6": [],
     "QScintilla2": [],
 }
-PlatformsBlackLists = {
+PlatformsBlockLists = {
     "freebsd": {
         "sip": [],
         "PyQt6": [],
@@ -1738,15 +1738,15 @@
         print("Alternatively you may install all of them with:")
         print("    {0} install-dependencies.py --all".format(sys.executable))
 
     # determine the platform dependent black list
     if sys.platform.startswith(("win", "cygwin")):
-        PlatformBlackLists = PlatformsBlackLists["windows"]
+        PlatformBlockLists = PlatformsBlockLists["windows"]
     elif sys.platform.startswith("linux"):
-        PlatformBlackLists = PlatformsBlackLists["linux"]
+        PlatformBlockLists = PlatformsBlockLists["linux"]
     elif sys.platform.startswith("freebsd"):
-        PlatformBlackLists = PlatformsBlackLists["freebsd"]
+        PlatformBlockLists = PlatformsBlockLists["freebsd"]
     else:
-        PlatformBlackLists = PlatformsBlackLists["mac"]
+        PlatformBlockLists = PlatformsBlockLists["mac"]
 
     print("\nVersion Information")
     print("-------------------")
@@ -1780,8 +1780,8 @@
                     )
                 )
                 exit(3)
-            # check for blacklisted versions
-            for vers in BlackLists["sip"] + PlatformBlackLists["sip"]:
+            # check for blocklisted versions
+            for vers in BlockLists["sip"] + PlatformBlockLists["sip"]:
                 if vers == sip.SIP_VERSION:
                     print(
                         "Sorry, sip version {0} is not compatible with eric.".format(
@@ -1806,8 +1806,8 @@
                 )
             )
             exit(4)
-        # check for blacklisted versions
-        for vers in BlackLists["PyQt6"] + PlatformBlackLists["PyQt6"]:
+        # check for blocklisted versions
+        for vers in BlockLists["PyQt6"] + PlatformBlockLists["PyQt6"]:
             if vers == PYQT_VERSION:
                 print(
                     "Sorry, PyQt version {0} is not compatible with eric.".format(
@@ -1835,8 +1835,8 @@
                 )
             )
             exit(5)
-        # check for blacklisted versions
-        for vers in BlackLists["QScintilla2"] + PlatformBlackLists["QScintilla2"]:
+        # check for blocklisted versions
+        for vers in BlockLists["QScintilla2"] + PlatformBlockLists["QScintilla2"]:
             if vers == QSCINTILLA_VERSION:
                 print(
                     "Sorry, QScintilla2 version {0} is not compatible with"
@@ -1738,15 +1738,15 @@
         print("    {0} install-dependencies.py --all".format(sys.executable))
 
-    # determine the platform dependent black list
+    # determine the platform dependent block list
     if sys.platform.startswith(("win", "cygwin")):

eric ide

mercurial